@@ -3,6 +3,7 @@
 """
 This module implements community detection.
 """
+from __future__ import print_function
 __all__ = ["partition_at_level", "modularity", "best_partition", "generate_dendogram", "induced_graph"]
 __author__ = """Thomas Aynaud (thomas.aynaud@lip6.fr)"""
 #    Copyright (C) 2009 by
@@ -56,7 +57,7 @@ def partition_at_level(dendogram, level) :
     """
     partition = dendogram[0].copy()
     for index in range(1, level + 1) :
-        for node, community in partition.iteritems() :
+        for node, community in partition.items() :
             partition[node] = dendogram[index][community]
     return partition
 
@@ -107,7 +108,7 @@ def modularity(partition, graph) :
     for node in graph :
         com = partition[node]
         deg[com] = deg.get(com, 0.) + graph.degree(node, weight = 'weight')
-        for neighbor, datas in graph[node].iteritems() :
+        for neighbor, datas in graph[node].items() :
             weight = datas.get("weight", 1)
             if partition[neighbor] == com :
                 if neighbor == node :
@@ -330,8 +331,7 @@ def __renumber(dictionary) :
 def __load_binary(data) :
     """Load binary graph as used by the cpp implementation of this algorithm
     """
-    if type(data) == types.StringType :
-        data = open(data, "rb")
+    data = open(data, "rb")
 
     reader = array.array("I")
     reader.fromfile(data, 1)
@@ -377,7 +377,7 @@ def __one_level(graph, status) :
                     neigh_communities.get(com_node, 0.), status)
             best_com = com_node
             best_increase = 0
-            for com, dnc in neigh_communities.iteritems() :
+            for com, dnc in neigh_communities.items() :
                 incr =  dnc  - status.degrees.get(com, 0.) * degc_totw
                 if incr > best_increase :
                     best_increase = incr
@@ -450,11 +450,11 @@ class Status :
             for node in graph.nodes() :
                 com = part[node]
                 self.node2com[node] = com
-                deg = float(graph.degree(node, weigh = 'weight'))
+                deg = float(graph.degree(node, weight = 'weight'))
                 self.degrees[com] = self.degrees.get(com, 0) + deg
                 self.gdegrees[node] = deg
                 inc = 0.
-                for neighbor, datas in graph[node].iteritems() :
+                for neighbor, datas in graph[node].items() :
                     weight = datas.get("weight", 1)
                     if weight <= 0 :
                         raise ValueError("Bad graph type, use positive weights")
@@ -473,7 +473,7 @@ def __neighcom(node, graph, status) :
     with the decomposition node2com
     """
     weights = {}
-    for neighbor, datas in graph[node].iteritems() :
+    for neighbor, datas in graph[node].items() :
         if neighbor != node :
             weight = datas.get("weight", 1)
             neighborcom = status.node2com[neighbor]
@@ -520,12 +520,12 @@ def main() :
         filename = sys.argv[1]
         graphfile = __load_binary(filename)
         partition = best_partition(graphfile)
-        print >> sys.stderr, str(modularity(partition, graphfile))
-        for elem, part in partition.iteritems() :
-            print str(elem) + " " + str(part)
+        print(str(modularity(partition, graphfile)), file=sys.stderr)
+        for elem, part in partition.items() :
+            print(str(elem) + " " + str(part))
     except (IndexError, IOError):
-        print "Usage : ./community filename"
-        print "find the communities in graph filename and display the dendogram"
-        print "Parameters:"
-        print "filename is a binary file as generated by the "
-        print "convert utility distributed with the C implementation"
+        print("Usage : ./community filename")
+        print("find the communities in graph filename and display the dendogram")
+        print("Parameters:")
+        print("filename is a binary file as generated by the ")
+        print("convert utility distributed with the C implementation")
